@@ -1,23 +1,23 @@
 module ServicesHelper
   def service_event_description(event)
     case event
-    when "push"
+    when "push", "push_events"
       "Event will be triggered by a push to the repository"
-    when "tag_push"
+    when "tag_push", "tag_push_events"
       "Event will be triggered when a new tag is pushed to the repository"
-    when "note"
+    when "note", "note_events"
       "Event will be triggered when someone adds a comment"
-    when "issue"
+    when "issue", "issue_events"
       "Event will be triggered when an issue is created/updated/closed"
-    when "confidential_issue"
+    when "confidential_issue", "confidential_issue_events"
       "Event will be triggered when a confidential issue is created/updated/closed"
-    when "merge_request"
+    when "merge_request", "merge_request_events"
       "Event will be triggered when a merge request is created/updated/merged"
-    when "build"
+    when "build", "build_events"
       "Event will be triggered when a build status changes"
-    when "wiki_page"
+    when "wiki_page", "wiki_page_events"
       "Event will be triggered when a wiki page is created/updated"
-    when "commit"
+    when "commit", "commit_events"
       "Event will be triggered when a commit is created/updated"
     end
   end
@@ -26,4 +26,6 @@ module ServicesHelper
     event = event.pluralize if %w[merge_request issue confidential_issue].include?(event)
     "#{event}_events"
   end
+
+  extend self
 end
