@@ -17,26 +17,50 @@ module Banzai
 
       def highlight_node(node)
         language = node.attr('class')
-        code     = node.text
+        code = node.text
+        css_classes = "code highlight"
+        lexer = lexer_for(language)
+        lang = lexer.tag
 
         begin
-          highlighted = block_code(code, language)
+          code = format(lex(lexer, code))
+
+          css_classes << " js-syntax-highlight #{lang}"
         rescue
+          lang = nil
           # Gracefully handle syntax highlighter bugs/errors to ensure
           # users can still access an issue/comment/etc.
-          highlighted = "<pre>#{code}</pre>"
         end
 
-        # Replace the parent `pre` element with the entire highlighted block
-        node.parent.replace(highlighted)
+        highlighted = %(<pre class="#{css_classes}" lang="#{lang}" v-pre="true"><code>#{code}</code></pre>)
+
+        # Extracted to a method to measure it
+        replace_parent_pre_element(node, highlighted)
       end
 
       private
 
+      # Separate method so it can be instrumented.
+      def lex(lexer, code)
+        lexer.lex(code)
+      end
+
+      def format(tokens)
+        rouge_formatter.format(tokens)
+      end
+
+      def lexer_for(language)
+        (Rouge::Lexer.find(language) || Rouge::Lexers::PlainText).new
+      end
+
+      def replace_parent_pre_element(node, highlighted)
+        # Replace the parent `pre` element with the entire highlighted block
+        node.parent.replace(highlighted)
+      end
+
       # Override Rouge::Plugins::Redcarpet#rouge_formatter
-      def rouge_formatter(lexer)
-        Rouge::Formatters::HTMLGitlab.new(
-          cssclass: "code highlight js-syntax-highlight #{lexer.tag}")
+      def rouge_formatter(lexer = nil)
+        @rouge_formatter ||= Rouge::Formatters::HTML.new
       end
     end
   end
