@@ -19,13 +19,14 @@ describe User, models: true do
     it { is_expected.to have_many(:project_members).dependent(:destroy) }
     it { is_expected.to have_many(:groups) }
     it { is_expected.to have_many(:keys).dependent(:destroy) }
+    it { is_expected.to have_many(:deploy_keys).dependent(:destroy) }
     it { is_expected.to have_many(:events).dependent(:destroy) }
     it { is_expected.to have_many(:recent_events).class_name('Event') }
     it { is_expected.to have_many(:issues).dependent(:destroy) }
     it { is_expected.to have_many(:notes).dependent(:destroy) }
-    it { is_expected.to have_many(:assigned_issues).dependent(:destroy) }
+    it { is_expected.to have_many(:assigned_issues).dependent(:nullify) }
     it { is_expected.to have_many(:merge_requests).dependent(:destroy) }
-    it { is_expected.to have_many(:assigned_merge_requests).dependent(:destroy) }
+    it { is_expected.to have_many(:assigned_merge_requests).dependent(:nullify) }
     it { is_expected.to have_many(:identities).dependent(:destroy) }
     it { is_expected.to have_one(:abuse_report) }
     it { is_expected.to have_many(:spam_logs).dependent(:destroy) }
@@ -48,7 +49,7 @@ describe User, models: true do
     describe '#project_members' do
       it 'does not include project memberships for which user is a requester' do
         user = create(:user)
-        project = create(:project, :public, :access_requestable)
+        project = create(:empty_project, :public, :access_requestable)
         project.request_access(user)
 
         expect(user.project_members).to be_empty
@@ -79,7 +80,7 @@ describe User, models: true do
     it { is_expected.to allow_value(0).for(:projects_limit) }
     it { is_expected.not_to allow_value(-1).for(:projects_limit) }
 
-    it { is_expected.to validate_length_of(:bio).is_within(0..255) }
+    it { is_expected.to validate_length_of(:bio).is_at_most(255) }
 
     it_behaves_like 'an object with email-formated attributes', :email do
       subject { build(:user) }
@@ -293,6 +294,34 @@ describe User, models: true do
     end
   end
 
+  shared_context 'user keys' do
+    let(:user) { create(:user) }
+    let!(:key) { create(:key, user: user) }
+    let!(:deploy_key) { create(:deploy_key, user: user) }
+  end
+
+  describe '#keys' do
+    include_context 'user keys'
+
+    context 'with key and deploy key stored' do
+      it 'returns stored key, but not deploy_key' do
+        expect(user.keys).to include key
+        expect(user.keys).not_to include deploy_key
+      end
+    end
+  end
+
+  describe '#deploy_keys' do
+    include_context 'user keys'
+
+    context 'with key and deploy key stored' do
+      it 'returns stored deploy key, but not normal key' do
+        expect(user.deploy_keys).to include deploy_key
+        expect(user.deploy_keys).not_to include key
+      end
+    end
+  end
+
   describe '#confirm' do
     before do
       allow_any_instance_of(ApplicationSetting).to receive(:send_user_confirmation_email).and_return(true)
@@ -386,13 +415,15 @@ describe User, models: true do
 
   describe 'projects' do
     before do
-      @user = create :user
-      @project = create :project, namespace: @user.namespace
-      @project_2 = create :project, group: create(:group) # Grant MASTER access to the user
-      @project_3 = create :project, group: create(:group) # Grant DEVELOPER access to the user
+      @user = create(:user)
 
-      @project_2.team << [@user, :master]
-      @project_3.team << [@user, :developer]
+      @project = create(:empty_project, namespace: @user.namespace)
+      @project_2 = create(:empty_project, group: create(:group)) do |project|
+        project.add_master(@user)
+      end
+      @project_3 = create(:empty_project, group: create(:group)) do |project|
+        project.add_developer(@user)
+      end
     end
 
     it { expect(@user.authorized_projects).to include(@project) }
@@ -435,7 +466,7 @@ describe User, models: true do
   describe 'namespaced' do
     before do
       @user = create :user
-      @project = create :project, namespace: @user.namespace
+      @project = create(:empty_project, namespace: @user.namespace)
     end
 
     it { expect(@user.several_namespaces?).to be_falsey }
@@ -517,7 +548,7 @@ describe User, models: true do
     before do
       User.delete_all
       @user = create :user
-      @project = create :project
+      @project = create(:empty_project)
     end
 
     it { expect(User.not_in_project(@project)).to include(@user, @project.owner) }
@@ -575,6 +606,23 @@ describe User, models: true do
         end
       end
     end
+
+    describe '#require_ssh_key?' do
+      protocol_and_expectation = {
+        'http' => false,
+        'ssh' => true,
+        '' => true,
+      }
+
+      protocol_and_expectation.each do |protocol, expected|
+        it "has correct require_ssh_key?" do
+          stub_application_setting(enabled_git_access_protocol: protocol)
+          user = build(:user)
+
+          expect(user.require_ssh_key?).to eq(expected)
+        end
+      end
+    end
   end
 
   describe '.find_by_any_email' do
@@ -741,6 +789,17 @@ describe User, models: true do
     end
   end
 
+  describe '.find_by_username' do
+    it 'returns nil if not found' do
+      expect(described_class.find_by_username('JohnDoe')).to be_nil
+    end
+
+    it 'is case-insensitive' do
+      user = create(:user, username: 'JohnDoe')
+      expect(described_class.find_by_username('JOHNDOE')).to eq user
+    end
+  end
+
   describe '.find_by_username!' do
     it 'raises RecordNotFound' do
       expect { described_class.find_by_username!('JohnDoe') }.
@@ -767,14 +826,14 @@ describe User, models: true do
   describe '#avatar_type' do
     let(:user) { create(:user) }
 
-    it "is true if avatar is image" do
+    it 'is true if avatar is image' do
       user.update_attribute(:avatar, 'uploads/avatar.png')
       expect(user.avatar_type).to be_truthy
     end
 
-    it "is false if avatar is html page" do
+    it 'is false if avatar is html page' do
       user.update_attribute(:avatar, 'uploads/avatar.html')
-      expect(user.avatar_type).to eq(["only images allowed"])
+      expect(user.avatar_type).to eq(['only images allowed'])
     end
   end
 
@@ -896,11 +955,11 @@ describe User, models: true do
     end
   end
 
-  describe "#starred?" do
-    it "determines if user starred a project" do
+  describe '#starred?' do
+    it 'determines if user starred a project' do
       user = create :user
-      project1 = create :project, :public
-      project2 = create :project, :public
+      project1 = create(:empty_project, :public)
+      project2 = create(:empty_project, :public)
 
       expect(user.starred?(project1)).to be_falsey
       expect(user.starred?(project2)).to be_falsey
@@ -923,10 +982,10 @@ describe User, models: true do
     end
   end
 
-  describe "#toggle_star" do
-    it "toggles stars" do
+  describe '#toggle_star' do
+    it 'toggles stars' do
       user = create :user
-      project = create :project, :public
+      project = create(:empty_project, :public)
 
       expect(user.starred?(project)).to be_falsey
       user.toggle_star(project)
@@ -936,42 +995,55 @@ describe User, models: true do
     end
   end
 
-  describe "#sort" do
+  describe '#sort' do
     before do
       User.delete_all
       @user = create :user, created_at: Date.today, last_sign_in_at: Date.today, name: 'Alpha'
       @user1 = create :user, created_at: Date.today - 1, last_sign_in_at: Date.today - 1, name: 'Omega'
+      @user2 = create :user, created_at: Date.today - 2, last_sign_in_at: nil, name: 'Beta'
     end
 
-    it "sorts users by the recent sign-in time" do
-      expect(User.sort('recent_sign_in').first).to eq(@user)
+    context 'when sort by recent_sign_in' do
+      it 'sorts users by the recent sign-in time' do
+        expect(User.sort('recent_sign_in').first).to eq(@user)
+      end
+
+      it 'pushes users who never signed in to the end' do
+        expect(User.sort('recent_sign_in').third).to eq(@user2)
+      end
     end
 
-    it "sorts users by the oldest sign-in time" do
-      expect(User.sort('oldest_sign_in').first).to eq(@user1)
+    context 'when sort by oldest_sign_in' do
+      it 'sorts users by the oldest sign-in time' do
+        expect(User.sort('oldest_sign_in').first).to eq(@user1)
+      end
+
+      it 'pushes users who never signed in to the end' do
+        expect(User.sort('oldest_sign_in').third).to eq(@user2)
+      end
     end
 
-    it "sorts users in descending order by their creation time" do
+    it 'sorts users in descending order by their creation time' do
       expect(User.sort('created_desc').first).to eq(@user)
     end
 
-    it "sorts users in ascending order by their creation time" do
-      expect(User.sort('created_asc').first).to eq(@user1)
+    it 'sorts users in ascending order by their creation time' do
+      expect(User.sort('created_asc').first).to eq(@user2)
     end
 
-    it "sorts users by id in descending order when nil is passed" do
-      expect(User.sort(nil).first).to eq(@user1)
+    it 'sorts users by id in descending order when nil is passed' do
+      expect(User.sort(nil).first).to eq(@user2)
     end
   end
 
   describe "#contributed_projects" do
     subject { create(:user) }
-    let!(:project1) { create(:project) }
-    let!(:project2) { create(:project, forked_from_project: project3) }
-    let!(:project3) { create(:project) }
+    let!(:project1) { create(:empty_project) }
+    let!(:project2) { create(:empty_project, forked_from_project: project3) }
+    let!(:project3) { create(:empty_project) }
     let!(:merge_request) { create(:merge_request, source_project: project2, target_project: project3, author: subject) }
-    let!(:push_event) { create(:event, action: Event::PUSHED, project: project1, target: project1, author: subject) }
-    let!(:merge_event) { create(:event, action: Event::CREATED, project: project3, target: merge_request, author: subject) }
+    let!(:push_event) { create(:event, :pushed, project: project1, target: project1, author: subject) }
+    let!(:merge_event) { create(:event, :created, project: project3, target: merge_request, author: subject) }
 
     before do
       project1.team << [subject, :master]
@@ -1010,12 +1082,12 @@ describe User, models: true do
 
   describe "#recent_push" do
     subject { create(:user) }
-    let!(:project1) { create(:project) }
-    let!(:project2) { create(:project, forked_from_project: project1) }
+    let!(:project1) { create(:project, :repository) }
+    let!(:project2) { create(:project, :repository, forked_from_project: project1) }
     let!(:push_data) do
       Gitlab::DataBuilder::Push.build_sample(project2, subject)
     end
-    let!(:push_event) { create(:event, action: Event::PUSHED, project: project2, target: project1, author: subject, data: push_data) }
+    let!(:push_event) { create(:event, :pushed, project: project2, target: project1, author: subject, data: push_data) }
 
     before do
       project1.team << [subject, :master]
@@ -1043,7 +1115,7 @@ describe User, models: true do
       expect(subject.recent_push(project2)).to eq(push_event)
 
       push_data1 = Gitlab::DataBuilder::Push.build_sample(project1, subject)
-      push_event1 = create(:event, action: Event::PUSHED, project: project1, target: project1, author: subject, data: push_data1)
+      push_event1 = create(:event, :pushed, project: project1, target: project1, author: subject, data: push_data1)
 
       expect(subject.recent_push([project1, project2])).to eq(push_event1) # Newest
     end
@@ -1085,7 +1157,7 @@ describe User, models: true do
 
     it "includes user's personal projects" do
       user    = create(:user)
-      project = create(:project, :private, namespace: user.namespace)
+      project = create(:empty_project, :private, namespace: user.namespace)
 
       expect(user.authorized_projects).to include(project)
     end
@@ -1093,7 +1165,7 @@ describe User, models: true do
     it "includes personal projects user has been given access to" do
       user1   = create(:user)
       user2   = create(:user)
-      project = create(:project, :private, namespace: user1.namespace)
+      project = create(:empty_project, :private, namespace: user1.namespace)
 
       project.team << [user2, Gitlab::Access::DEVELOPER]
 
@@ -1102,7 +1174,7 @@ describe User, models: true do
 
     it "includes projects of groups user has been added to" do
       group   = create(:group)
-      project = create(:project, group: group)
+      project = create(:empty_project, group: group)
       user    = create(:user)
 
       group.add_developer(user)
@@ -1112,7 +1184,7 @@ describe User, models: true do
 
     it "does not include projects of groups user has been removed from" do
       group   = create(:group)
-      project = create(:project, group: group)
+      project = create(:empty_project, group: group)
       user    = create(:user)
 
       member = group.add_developer(user)
@@ -1124,7 +1196,7 @@ describe User, models: true do
 
     it "includes projects shared with user's group" do
       user    = create(:user)
-      project = create(:project, :private)
+      project = create(:empty_project, :private)
       group   = create(:group)
 
       group.add_reporter(user)
@@ -1136,7 +1208,7 @@ describe User, models: true do
     it "does not include destroyed projects user had access to" do
       user1   = create(:user)
       user2   = create(:user)
-      project = create(:project, :private, namespace: user1.namespace)
+      project = create(:empty_project, :private, namespace: user1.namespace)
 
       project.team << [user2, Gitlab::Access::DEVELOPER]
       expect(user2.authorized_projects).to include(project)
@@ -1147,7 +1219,7 @@ describe User, models: true do
 
     it "does not include projects of destroyed groups user had access to" do
       group   = create(:group)
-      project = create(:project, namespace: group)
+      project = create(:empty_project, namespace: group)
       user    = create(:user)
 
       group.add_developer(user)
@@ -1162,14 +1234,9 @@ describe User, models: true do
     let(:user) { create(:user) }
 
     it 'includes projects for which the user access level is above or equal to reporter' do
-      create(:project)
-      reporter_project = create(:project)
-      developer_project = create(:project)
-      master_project = create(:project)
-
-      reporter_project.team << [user, :reporter]
-      developer_project.team << [user, :developer]
-      master_project.team << [user, :master]
+      reporter_project  = create(:empty_project) { |p| p.add_reporter(user) }
+      developer_project = create(:empty_project) { |p| p.add_developer(user) }
+      master_project    = create(:empty_project) { |p| p.add_master(user) }
 
       expect(user.projects_where_can_admin_issues.to_a).to eq([master_project, developer_project, reporter_project])
       expect(user.can?(:admin_issue, master_project)).to eq(true)
@@ -1178,10 +1245,8 @@ describe User, models: true do
     end
 
     it 'does not include for which the user access level is below reporter' do
-      project = create(:project)
-      guest_project = create(:project)
-
-      guest_project.team << [user, :guest]
+      project = create(:empty_project)
+      guest_project = create(:empty_project) { |p| p.add_guest(user) }
 
       expect(user.projects_where_can_admin_issues.to_a).to be_empty
       expect(user.can?(:admin_issue, guest_project)).to eq(false)
@@ -1189,15 +1254,14 @@ describe User, models: true do
     end
 
     it 'does not include archived projects' do
-      project = create(:project)
-      project.update_attributes(archived: true)
+      project = create(:empty_project, :archived)
 
       expect(user.projects_where_can_admin_issues.to_a).to be_empty
       expect(user.can?(:admin_issue, project)).to eq(false)
     end
 
     it 'does not include projects for which issues are disabled' do
-      project = create(:project, issues_access_level: ProjectFeature::DISABLED)
+      project = create(:empty_project, :issues_disabled)
 
       expect(user.projects_where_can_admin_issues.to_a).to be_empty
       expect(user.can?(:admin_issue, project)).to eq(false)
@@ -1213,7 +1277,7 @@ describe User, models: true do
     end
 
     context 'without any projects' do
-      let(:project) { create(:project) }
+      let(:project) { create(:empty_project) }
 
       it 'does not load' do
         expect(user.ci_authorized_runners).to be_empty
@@ -1222,7 +1286,7 @@ describe User, models: true do
 
     context 'with personal projects runners' do
       let(:namespace) { create(:namespace, owner: user) }
-      let(:project) { create(:project, namespace: namespace) }
+      let(:project) { create(:empty_project, namespace: namespace) }
 
       it 'loads' do
         expect(user.ci_authorized_runners).to contain_exactly(runner)
@@ -1253,7 +1317,7 @@ describe User, models: true do
 
     context 'with groups projects runners' do
       let(:group) { create(:group) }
-      let(:project) { create(:project, group: group) }
+      let(:project) { create(:empty_project, group: group) }
 
       def add_user(access)
         group.add_user(user, access)
@@ -1263,7 +1327,7 @@ describe User, models: true do
     end
 
     context 'with other projects runners' do
-      let(:project) { create(:project) }
+      let(:project) { create(:empty_project) }
 
       def add_user(access)
         project.team << [user, access]
@@ -1293,8 +1357,8 @@ describe User, models: true do
   end
 
   describe '#projects_with_reporter_access_limited_to' do
-    let(:project1) { create(:project) }
-    let(:project2) { create(:project) }
+    let(:project1) { create(:empty_project) }
+    let(:project2) { create(:empty_project) }
     let(:user) { create(:user) }
 
     before do
@@ -1328,6 +1392,39 @@ describe User, models: true do
     end
   end
 
+  describe '#nested_groups' do
+    let!(:user) { create(:user) }
+    let!(:group) { create(:group) }
+    let!(:nested_group) { create(:group, parent: group) }
+
+    before do
+      group.add_owner(user)
+
+      # Add more data to ensure method does not include wrong groups
+      create(:group).add_owner(create(:user))
+    end
+
+    it { expect(user.nested_groups).to eq([nested_group]) }
+  end
+
+  describe '#nested_projects' do
+    let!(:user) { create(:user) }
+    let!(:group) { create(:group) }
+    let!(:nested_group) { create(:group, parent: group) }
+    let!(:project) { create(:empty_project, namespace: group) }
+    let!(:nested_project) { create(:empty_project, namespace: nested_group) }
+
+    before do
+      group.add_owner(user)
+
+      # Add more data to ensure method does not include wrong projects
+      other_project = create(:empty_project, namespace: create(:group, :nested))
+      other_project.add_developer(create(:user))
+    end
+
+    it { expect(user.nested_projects).to eq([nested_project]) }
+  end
+
   describe '#refresh_authorized_projects', redis: true do
     let(:project1) { create(:empty_project) }
     let(:project2) { create(:empty_project) }
@@ -1354,4 +1451,37 @@ describe User, models: true do
       expect(user.project_authorizations.where(access_level: Gitlab::Access::REPORTER).exists?).to eq(true)
     end
   end
+
+  describe '#access_level=' do
+    let(:user) { build(:user) }
+
+    it 'does nothing for an invalid access level' do
+      user.access_level = :invalid_access_level
+
+      expect(user.access_level).to eq(:regular)
+      expect(user.admin).to be false
+    end
+
+    it "assigns the 'admin' access level" do
+      user.access_level = :admin
+
+      expect(user.access_level).to eq(:admin)
+      expect(user.admin).to be true
+    end
+
+    it "doesn't clear existing access levels when an invalid access level is passed in" do
+      user.access_level = :admin
+      user.access_level = :invalid_access_level
+
+      expect(user.access_level).to eq(:admin)
+      expect(user.admin).to be true
+    end
+
+    it "accepts string values in addition to symbols" do
+      user.access_level = 'admin'
+
+      expect(user.access_level).to eq(:admin)
+      expect(user.admin).to be true
+    end
+  end
 end
